@@ -1,6 +1,8 @@
 {
 	modules => [qw(YAML)],
 	modules_init => {
+		YAML => {
+		},
 	},
 }
 
